TransD
======

.. currentmodule:: pykeen.models

.. autoclass:: TransD
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransD.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransD.interaction_function
      ~TransD.score_h
      ~TransD.score_hrt
      ~TransD.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: interaction_function
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
